@@ -3,7 +3,7 @@ library(testthat)
 context("Test the simulate arguments")
 
 test_that("Argument dest works well", {
-  model <- model_library$advan4_trans4
+  model <- model_suite$nonmem$advan4_trans4
   
   dataset <- Dataset() %>%
     add(Bolus(time=0, amount=1000, compartment=1)) %>%
@@ -19,7 +19,7 @@ test_that("Argument dest works well", {
 })
 
 test_that("Auto seed value vs fix seed + default engine", {
-  model <- model_library$advan4_trans4
+  model <- model_suite$nonmem$advan4_trans4
   
   dataset <- Dataset() %>%
     add(Bolus(time=0, amount=1000, compartment=1)) %>%
@@ -39,4 +39,4 @@ test_that("Auto seed value vs fix seed + default engine", {
   results2 <- model %>% simulate(dataset=dataset, seed=10) # Fixed
   expect_false(all(results1$CP==results2$CP))
   
-})
\ No newline at end of file
+})
