@@ -6,7 +6,7 @@ seed <- 1
 source(paste0("", "testUtils.R"))
 
 test_that(getTestName("Simulate a bolus, 2 arms, F1 only in arm1, in dataset"), {
-  model <- model_library$advan4_trans4
+  model <- model_suite$nonmem$advan4_trans4
   regFilename <- "bolus_2arms_bioavailability"
   
   arm1 <- Arm(1, subjects=10) %>%
@@ -31,7 +31,7 @@ test_that(getTestName("Simulate a bolus, 2 arms, F1 only in arm1, in dataset"),
 })
 
 test_that(getTestName("Simulate a simple bolus with bioavailability, dataset versus model"), {
-  model <- model_library$advan4_trans4
+  model <- model_suite$nonmem$advan4_trans4
   regFilename <- "simple_bolus_bioavailability"
   
   # Bioavailability implemented in dataset
@@ -65,7 +65,7 @@ test_that(getTestName("Simulate a simple bolus with bioavailability, dataset ver
 
 
 test_that(getTestName("Simulate several fixed F's at once"), {
-  model <- model_library$advan4_trans4
+  model <- model_suite$nonmem$advan4_trans4
 
   # Bioavailability implemented in dataset
   dataset <- Dataset(4) %>%
