@@ -9,7 +9,7 @@ test_that(getTestName("Bolus and infusion in CMT 1"), {
   
   regFilename <- "bolus_infusion_same_cmt"
   
-  model <- model_library$advan4_trans4
+  model <- model_suite$nonmem$advan4_trans4
   model <- model %>% add(InfusionDuration(compartment=1, rhs="5"))
  
   dataset <- Dataset(1)%>%
