@@ -6,7 +6,7 @@ seed <- 1
 source(paste0("", "testUtils.R"))
 
 test_that("Declare argument with mrgsolve", {
-  model <- model_library$advan4_trans4
+  model <- model_suite$nonmem$advan4_trans4
   model <- model %>% replace(Equation("KA", "THETA_KA*exp(ETA_KA + SOMETHING)"))
   regFilename <- "simple_bolus"
   
@@ -29,9 +29,9 @@ test_that("Declare argument with mrgsolve", {
       expect_error(model %>% simulate(dataset, dest=destEngine, seed=seed, tablefun=tablefun))
       
       # mrgsolve does not complain if SOMETHING variable is declared
-      results <- model %>% simulate(dataset, dest=destEngine, seed=seed, tablefun=tablefun, declare="SOMETHING")
+      results <- model %>% simulate(dataset, dest=destEngine, seed=seed, tablefun=tablefun, settings=Settings(Declare("SOMETHING")))
       outputRegressionTest(results, output="CP", filename=regFilename)
     }
   )
   campsisTest(expression(), test, env=environment())
-})
\ No newline at end of file
+})
