@@ -7,7 +7,7 @@ source(paste0("", "testUtils.R"))
 
 test_that(getTestName("Clear central compartment events"), {
   if (skipLongTest) return(TRUE)
-  model <- model_library$advan4_trans4
+  model <- model_suite$nonmem$advan4_trans4
   regFilename <- "clear_central_event"
   
   dataset <- Dataset(3) %>%
@@ -31,7 +31,7 @@ test_that(getTestName("Clear central compartment events"), {
 
 test_that(getTestName("Give daily dose in absortion"), {
   if (skipLongTest) return(TRUE)
-  model <- model_library$advan4_trans4
+  model <- model_suite$nonmem$advan4_trans4
   regFilename <- "event_daily_dose"
   
   dataset <- Dataset(3) %>%
@@ -54,7 +54,7 @@ test_that(getTestName("Give daily dose in absortion"), {
 
 test_that(getTestName("Daily dose in dataset + daily dose through events"), {
   if (skipLongTest) return(TRUE)
-  model <- model_library$advan4_trans4
+  model <- model_suite$nonmem$advan4_trans4
   regFilename <- "event_daily_dose"
   
   dataset <- Dataset(3) %>%
@@ -78,7 +78,7 @@ test_that(getTestName("Daily dose in dataset + daily dose through events"), {
 
 test_that(getTestName("Body weight as an event covariate"), {
   if (skipLongTest) return(TRUE)
-  model <- model_library$advan2_trans2
+  model <- model_suite$nonmem$advan2_trans2
   equation <- model %>% find(Equation("CL"))
   model <- model %>% replace(Equation("CL", paste0(equation@rhs, "*pow(BW/70, 0.75)")))
   regFilename <- "event_varying_bw"
@@ -111,7 +111,7 @@ test_that(getTestName("Body weight as an event covariate"), {
 
 test_that(getTestName("Dose adaptation based on Ctrough"), {
   if (skipLongTest) return(TRUE)
-  model <- model_library$advan2_trans2
+  model <- model_suite$nonmem$advan2_trans2
   regFilename <- "dose_adaptation_ctrough"
   
   dataset <- Dataset(5)
