@@ -8,14 +8,14 @@ source(paste0("", "testUtils.R"))
 
 test_that(getTestName("VPC on CP, using predicate"), {
   if (skipLongTest) return(TRUE)
-  model <- model_library$my_model1
+  model <- model_suite$other$my_model1
   model <- model %>% disable(c("VARCOV_OMEGA", "VARCOV_SIGMA"))
   regFilename <- "full_uncertainty"
-  
+
   ds <- Dataset(100) %>%
     add(Infusion(time=0, amount=1000, compartment=1, ii=24, addl=2)) %>%
     add(Observations(times=seq(0, 3*24, by=4)))
-  
+
   simulation <- expression(simulate(model=model, dataset=ds, dest=destEngine, replicates=5, outfun=~PI(.x, output="CP"), seed=seed))
   test <- expression(
     vpcOutputRegressionTest(results, output="CP", filename=regFilename)
@@ -25,7 +25,7 @@ test_that(getTestName("VPC on CP, using predicate"), {
 
 test_that(getTestName("VPC on both CP and Y, using function"), {
   if (skipLongTest) return(TRUE)
-  model <- model_library$my_model1
+  model <- model_suite$other$my_model1
   model <- model %>% disable(c("VARCOV_OMEGA", "VARCOV_SIGMA"))
   regFilename <- "full_uncertainty"
 
@@ -49,15 +49,15 @@ test_that(getTestName("VPC on both CP and Y, using function"), {
 
 test_that(getTestName("Study replication also works with scenarios"), {
   if (skipLongTest) return(TRUE)
-  model <- model_library$advan2_trans1
+  model <- model_suite$nonmem$advan2_trans1
   ds <- Dataset(10) %>%
     add(Bolus(time=0, amount=1000)) %>%
     add(Observations(times=c(0,1,2,4,8,12)))
-  
+
   scenarios <- Scenarios() %>%
     add(Scenario(name="Base model")) %>%
     add(Scenario(name="Increased KA", model=~.x %>% replace(Theta(name="KA", value=3)))) # 3 instead of 1
-  
+
   simulation <- expression(simulate(model=model, dataset=ds, dest=destEngine, replicates=5,
                                     outfun=~PI(.x, output="CP"), seed=seed, scenarios=scenarios))
   test <- expression(
@@ -70,19 +70,19 @@ test_that(getTestName("Study replication also works with scenarios"), {
 
 test_that(getTestName("Try/catch works as expected if one replicate fails"), {
   if (skipLongTest) return(TRUE)
-  model <- model_library$advan2_trans2
-  
+  model <- model_suite$nonmem$advan2_trans2
+
   # Add high uncertainty on THETA_KA (variance of 1)
   varcov <- matrix(1)
   row.names(varcov) <- "THETA_KA"
   colnames(varcov) <- "THETA_KA"
-  
+
   model@parameters@varcov <- varcov
-  
-  dataset <- Dataset(10) %>% 
+
+  dataset <- Dataset(10) %>%
     add(Bolus(time=0, amount=10, compartment=1)) %>%
     add(Observations(c(0,1,2,4,8,10000)))
-  
+
   test <- expression(
     if (destEngine %in% c("RxODE", "rxode2")) {
       # Simulation with RxODE
@@ -103,3 +103,38 @@ test_that(getTestName("Try/catch works as expected if one replicate fails"), {
   )
   campsisTest(expression(), test, env=environment())
 })
+
+test_that(getTestName("Replicates can be simulated in parallel"), {
+  if (skipLongTest) return(TRUE)
+  # progressr::handlers(global=TRUE)
+  # progressr::handlers(campsis_handler())
+  regFilename <- "replicates_in_parallel"
+  
+  model <- model_suite$pk$`1cpt_fo` %>%
+    add(Equation("EPSILON", "EPS_RUV_FIX"), pos=Position(ErrorRecord()))
+  
+  dataset <- Dataset(25) %>%
+    add(Bolus(time=0, amount=1000)) %>%
+    add(Observations(times=c(12)))
+  
+  # Running 25 replicates with 2 CPU's
+  settings <- Settings(Hardware(cpu=2, replicate_parallel=TRUE))
+  
+  simulation <- expression(simulate(model=model, dataset=dataset, dest=destEngine, replicates=25, seed=seed, settings=settings))
+  test <- expression(
+    expect_equal(results$EPSILON %>% unique() %>% length(), 625), # Check RUV is unique
+    outputRegressionTest(results, output="CONC", filename=regFilename)
+  )
+  campsisTest(simulation, test, env=environment())
+  
+  # Running 25 replicates with only 1 CPU
+  setupPlanSequential()
+  settings <- Settings()
+  
+  simulation <- expression(simulate(model=model, dataset=dataset, dest=destEngine, replicates=25, seed=seed, settings=settings))
+  test <- expression(
+    expect_equal(results$EPSILON %>% unique() %>% length(), 625), # Check RUV is unique
+    outputRegressionTest(results, output="CONC", filename=regFilename)
+  )
+  campsisTest(simulation, test, env=environment())
+})
