@@ -6,7 +6,7 @@ seed <- 1
 source(paste0("", "testUtils.R"))
 
 test_that(getTestName("Body weight as a true time varying covariate"), {
-  model <- model_library$advan2_trans2
+  model <- model_suite$nonmem$advan2_trans2
   equation <- model %>% find(Equation("CL"))
   model <- model %>% replace(Equation("CL", paste0(equation@rhs, "*pow(BW/70, 0.75)")))
   regFilename <- "event_varying_bw"
@@ -16,7 +16,8 @@ test_that(getTestName("Body weight as a true time varying covariate"), {
     add(Observations(times=seq(0,24*2, by=1))) %>%
     add(TimeVaryingCovariate("BW", data.frame(TIME=c(0,15,30), VALUE=c(100, 60, 30))))
   
-  simulation <- expression(simulate(model=model, dataset=dataset, dest=destEngine, seed=seed, outvars="BW", nocbvars="BW"))
+  simulation <- expression(simulate(model=model, dataset=dataset, dest=destEngine,
+                                    seed=seed, outvars="BW", settings=Settings(NOCB(variables="BW"))))
   test <- expression(
     outputRegressionTest(results, output="CP", filename=regFilename)
   )
@@ -24,7 +25,7 @@ test_that(getTestName("Body weight as a true time varying covariate"), {
 })
 
 test_that(getTestName("Body weight as a true time varying covariate, 2 arms, individual body weights"), {
-  model <- model_library$advan2_trans2
+  model <- model_suite$nonmem$advan2_trans2
   equation <- model %>% find(Equation("CL"))
   model <- model %>% replace(Equation("CL", paste0(equation@rhs, "*pow(BW/70, 0.75)")))
   regFilename <- "event_varying_bw_2arms_ind"
@@ -47,11 +48,11 @@ test_that(getTestName("Body weight as a true time varying covariate, 2 arms, ind
   ds <- Dataset() %>% add(c(arm1, arm2))
   
   simulation <- expression(simulate(model=model %>% disable("IIV"), dataset=ds,
-                                    dest=destEngine, seed=seed, outvars="BW", nocbvars="BW"))
+                                    dest=destEngine, seed=seed, outvars="BW", settings=Settings(NOCB(variables="BW"))))
   test <- expression(
     spaghettiPlot(results, "CP", "ID"),
     spaghettiPlot(results, "BW", "ID"),
     outputRegressionTest(results, output="CP", filename=regFilename)
   )
   campsisTest(simulation, test, env=environment())
-})
\ No newline at end of file
+})
