@@ -9,8 +9,8 @@ testFolder <- ""
 skipLongTest <- TRUE
 testEngines <- c("rxode2", "mrgsolve")
 
-datasetInMemory <- function(dataset, model=NULL, seed, doseOnly=TRUE) {
-  table <- dataset %>% export(dest="RxODE", model=model, seed=seed)
+datasetInMemory <- function(dataset, model=NULL, seed, doseOnly=TRUE, settings, dest) {
+  table <- dataset %>% export(dest=dest, model=model, seed=seed, settings=settings)
   
   # Keep doses only
   if (doseOnly) {
@@ -26,9 +26,11 @@ datasetInMemory <- function(dataset, model=NULL, seed, doseOnly=TRUE) {
 #' @param seed seed that was used for export
 #' @param doseOnly look only at the doses, i.e. EVID==1
 #' @param filename reference file
+#' @param settings export settings
+#' @param dest destination engine
 #' @export
-datasetRegressionTest <- function(dataset, model=NULL, seed, doseOnly=TRUE, filename) {
-  dataset1 <- datasetInMemory(dataset=dataset, model=model, seed=seed, doseOnly=doseOnly)
+datasetRegressionTest <- function(dataset, model=NULL, seed, doseOnly=TRUE, filename, settings=Settings(), dest="RxODE") {
+  dataset1 <- datasetInMemory(dataset=dataset, model=model, seed=seed, doseOnly=doseOnly, settings=settings, dest=dest)
   dataset1 <- dataset1 %>% dplyr::mutate_if(is.numeric, round, digits=6)
   
   file <- paste0(testFolder, "non_regression/", paste0(filename, ".csv"))
